Task: QA-SRL Semantic Role Labeling
====================================
Description: QA dataset implemented as part of the DecaNLP task. More info on thedataset can be found here: https://dada.cs.washington.edu/qasrl/

Tags: #qasrl, #All, #decanlp

